#
# spec file for package deepin-launcher
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name dde-launcher

Name:           deepin-launcher
Version:        5.6.1
Release:        1.3
Summary:        Deepin Launcher
License:        GPL-3.0-or-later
URL:            https://github.com/linuxdeepin/dde-launcher
Source0:        https://github.com/linuxdeepin/dde-launcher/archive/%{version}/%{_name}-%{version}.tar.gz
Group:          System/GUI/Other
# PATCH-FIX-UPSTREAM fix-include-dir.patch hillwood@opensuse.org - Make sure the compiler can find DtkGui headers
Patch0:         fix-include-dir.patch
# PATCH-FIX-UPSTREAM fix-ambiguous-error.patch hillwood@opensuse.org - Skip the ambiguous error
Patch1:         fix-ambiguous-error.patch
# https://github.com/linuxdeepin/dde-launcher/commit/0612c1181f232eb1c7be05a40c9c951a51cd0f2a
Patch2:         fix-stuck-issue.patch
BuildRequires:  cmake
BuildRequires:  gtest
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(dframeworkdbus) >= 0.4.1
BuildRequires:  pkgconfig(dtkcore) >= 5.0.0
BuildRequires:  pkgconfig(dtkwidget) >= 5.0.0
BuildRequires:  pkgconfig(gsettings-qt)
BuildRequires:  pkgconfig(xcb-ewmh)
Requires:       dbus-1
Requires:       deepin-daemon
Requires:       deepin-desktop-schemas >= 5.9.3
Requires:       deepin-start

%description
Deepin desktop-environment - Launcher module

%lang_package

%prep
%autosetup -p1 -n %{_name}-%{version}
sed -i 's|lrelease|lrelease-qt5|g' translate_generation.sh

%build
%cmake -DWITHOUT_UNINSTALL_APP=1
%cmake_build

%install
%cmake_install
%find_lang %{_name} --with-qt

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/%{_name}
%{_bindir}/%{_name}-wapper
%{_datadir}/applications/%{_name}.desktop
%{_datadir}/dbus-1/services/*.service
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/glib-2.0/schemas/com.deepin.dde.launcher.gschema.xml
%dir %{_datadir}/%{_name}
%dir %{_datadir}/%{_name}/translations
%{_datadir}/%{_name}/translations/dde-launcher.qm
%dir %{_datadir}/dsg
%dir %{_datadir}/dsg/configs
%dir %{_datadir}/dsg/configs/org.deepin.dde.launcher
%{_datadir}/dsg/configs/org.deepin.dde.launcher/org.deepin.dde.launcher.json

%files lang -f %{_name}.lang
%if 0%{?suse_version} <= 1500
# unusual languages not autodetected by find_lang (boo#1187036)
%lang(ast) %{_datadir}/%{_name}/translations/dde-launcher_ast.qm
%lang(fil) %{_datadir}/%{_name}/translations/dde-launcher_fil.qm
%lang(kab) %{_datadir}/%{_name}/translations/dde-launcher_kab.qm
%lang(pam) %{_datadir}/%{_name}/translations/dde-launcher_pam.qm
%endif

%changelog
* Mon Jan 30 2023 Hillwood Yang <hillwood@opensuse.org>
- Add fix-stuck-issue.patch, fix a stuck issue
* Mon Jan 16 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.6.1
  * Fix bugs
- Add fix-include-dir.patch, Make sure the compiler can find DtkGui headers
- fix-ambiguous-error.patch, Skip the ambiguous error
* Thu Nov 24 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.37
  * Fix bugs
  * Update translations
  * Update documents
* Wed Sep 28 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.33
  * Fix bugs
* Wed Aug 24 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.31
  * Fix bugs
  * Feature: hide main window after losting active point
* Tue Jun 28 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.19
  * Fix bugs
* Wed Apr 13 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.11
  * Fix bugs
  * Optimize wayland support
* Thu Dec 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.60
  * Fix bugs
* Sun Jul 25 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.24
  * Optimize test modules
  * Optimize starting
  * Fix bugs
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.4.11
  * Bug fixes
  * Feature: Allow configure the right-click menu of the application
    to be displayed or hidden
- Use find_lang macro
* Tue May  4 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.5
  * Optimize menu
  * Configure ci
  * Fix bugs
  * Update translations
* Mon Mar 15 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.4
  * Add com.deepin.dde.launcher schema profile
  * Add some new features
* Tue Feb 23 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.3.0.45
  * fix bugs
  * optimize the launcher app list view redraw performance
  * launcher remove all QGraphicsxxx
* Thu Jul 18 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.6.14
  * Remove unused deepin-qt5config
  * Disable uninstall dde-introduction
  * Disable uninstall for deepin-terminal
  * Fix unable to launch app in category list search
  * Fix the coordinates of the entervent are incorrect after the menu is closed
  * Fux fullScreen: category list coordinate error
* Mon Apr 15 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.6.9
  * Fix will flash on the sw platform
  * Fix Category heading is truncated
  * Fix Window: When the dock is on the right, the position is not close
  * category button support dynamic font size
  * backspace do not work in window mode search edit
  * Box: search result page has no height adjustment
  * dragging icon size error in fullscreen frame
  * show launcher on lock
  * compile-time option to disable uninstall
  * Fix Background:**  gradient not update when background changed
  * Fix FullScreen: not set origin size
  * Fix delete selected text when append new char to search bar
  * Fix Mini: replace search widget
  * Fix Mini: cannot enter category when not scroll view
  * Fix Mini: compatible with Qt5.6 * optimized application list sorting
    algorithm on mini mode
  * background: refresh background
  * Fix update scroll interval
  * Fix mini: auto change font size
  * fullscreen: support kwin
  * focus keyboard switch.
  * add DTK version check
  * Fix Mini: use DWindowManagerHelper::currentWorkSpaceWindowIdList
  * Fix Mini: stop the inertial scrolling of the head and bottom
  * Fix cannot launcher app
  * Fix Mini: cannot click
  * support touch scroll
  * check deepin-manual
  * Mini: don't hide when using virtual keyboard
  * Mini: average startup number sort
  * Fix Mini: disable verticalScroll context menu
  * Fix tips label is not hidden.
  * Fix auto exit
  * Fix scroll down is very short
  * Fix Mini:cannot hide
  * Fix Multi-screen coordinates
  * Fix windowed_frame: width calculation is incorrect.
  * add regionMonitorPoint interface
  * Mini: support vertical scrollbar show as needed
  * support back tab key
  * support change frame opacity
  * disable animation when scroll for sw
  * optimization switch mode
  * support Ctrl+V shortcuts to pasted text to the search widget
  * windowed_frame: adaptive window width.
  * Fix content highly adaptable to dock's position
  * Fix mission disable animation macro
  * Fix background shift
  * Fix geometry error
  * Fix don't show when not have app infos
  * Fix Incorrect return reference
  * Fix check all app info is vaild
  * Fix current index is incorrect
  * Fix size error when dock's position is right
  * Fix draw background error after changing the dock position
  * Fix Mini: double hide launcher
  * Fix sw: mission mieee
  * Fix windowed: more perfect scrolling.
* Thu Mar 22 2018 hillwood@opensuse.org
- Update version to 4.3.2
  * Fix autostart mark indicator position error in HiDPI.
  * Add auto-exit timer.
  * Support mouse wheel to adjust icon size.
  * Hide frame when popup uninstall dialog.
  * Adapt lintian.
  * Fix window position error in mini mode.
  * Fix autostart icon disappear.
  * Fix show paint error when show_detail.
  * Fix not display chainsproxy when not configuration.
  * Fix background bug.
  * Fix menu bug.
  * Fix miniframe bug.
  * Fix item not update when move to new one.
  * Fix position error.
  * Update translate files.
  * Add menu option to disable HiDPI-scale on application.
* Wed Nov 29 2017 hillwood@opensuse.org
- Update to 4.2.6
  * Improve HiDPI painting
  * Update translations.
  * Improve item icon adjust policy.
  * Improve graphics paint algorithm.
  * Fix: uninstll dialog icon too smaill at HiDPI screen.
  * Feature: Hide frame when uninstall dialog popup.
  * Fix: startup mark icon placed pos error
  * Fix autostart icon disappear
  * HiDPI Support
  * Minor bug fixes
* Sun Nov 12 2017 hillwood@opensuse.org
- Cleanup spec.
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
